@@ -46,6 +46,9 @@ else:
     addMapping(BASE_FONT_NAME, 1, 0, BASE_FONT_NAME + '-Bold')
     addMapping(BASE_FONT_NAME, 1, 1, BASE_FONT_NAME + '-BoldOblique')
 
+from reportlab.graphics import renderPDF
+from reportlab.graphics.shapes import Drawing
+from reportlab.graphics.barcode.qr import QrCodeWidget
 from reportlab.lib import colors
 from reportlab.lib.enums import TA_CENTER
 from reportlab.lib.pagesizes import A4, landscape
@@ -159,7 +162,7 @@ def reduce_fontsize_to_fit_width(text, maxwidth, *styles):
             mainstyle = copies[0]
 
         for style in copies:
-            style.fontSize -= 2
+            style.fontSize -= 1
             style.leading = style.fontSize * 1.1
 
     return copies
@@ -251,10 +254,12 @@ class BasicPrintout(object):
             title='%s: %s' % (self.getTitle(), self.getSubTitle()))
 
         title_height = 3.0*cm
-        title_frame = Frame(doc.leftMargin,
-                            doc.height + doc.bottomMargin - title_height,
-                            doc.width,
-                            title_height)
+        title_width = doc.width
+        if self.lit_url is not None:
+            title_width -= title_height
+        title_frame = Frame(doc.leftMargin, doc.height + doc.bottomMargin - title_height,
+                            title_width, title_height)
+        self.title_width = title_width
 
         fp_frames = [title_frame]
         lp_frames = []
@@ -347,11 +352,28 @@ class BasicPrintout(object):
         canvas.drawString(hl, fh, self.getLeftFooter())
         canvas.drawCentredString(hc, fh, self.getCenterFooter())
         canvas.drawRightString(hr, fh, self.getRightFooter())
+
+        if doc.page == 1 and self.lit_url is not None:
+            qr = QrCodeWidget(self.lit_url)
+            bounds = qr.getBounds()
+            qrw = bounds[2] - bounds[0]
+            qrh = bounds[2] - bounds[1]
+            size = 3*cm
+            drawing = Drawing(size, size, transform=[size/qrw, 0, 0, size/qrh, 0, 0])
+            drawing.add(qr)
+            renderPDF.draw(drawing, canvas,
+                           w - doc.leftMargin - size,
+                           h - doc.topMargin - size)
+
         canvas.restoreState()
 
-    def execute(self):
-        "Create and build the document."
+    def execute(self, request):
+        """Create and build the document.
 
+        :param request: the Pyramid request instance
+        """
+
+        self.lit_url = self.getLitURL(request)
         self.createDocument()
         self.doc.build(list(self.getElements()))
 
@@ -361,6 +383,14 @@ class BasicPrintout(object):
         raise NotImplementedError("%s should implement this method!"
                                   % self.__class__)
 
+    def getLitURL(self, request):
+        """Compute the Lit URL for this printout, if any.
+
+        :param request: the Pyramid request instance
+        """
+
+        return None
+
 
 class TourneyPrintout(BasicPrintout):
     "Basic tourney printout, to be further specialized."
@@ -429,8 +459,7 @@ class TourneyPrintout(BasicPrintout):
         "Yield basic elements for the title frame in the first page."
 
         title = self.getTitle()
-        maxwidth = self.doc.width - 1*cm
-        tstyle, ststyle = reduce_fontsize_to_fit_width(title, maxwidth,
+        tstyle, ststyle = reduce_fontsize_to_fit_width(title, self.title_width - 1*cm,
                                                        title_style, subtitle_style)
 
         yield Paragraph(title, tstyle)
@@ -540,6 +569,10 @@ class Ranking(TourneyPrintout):
         super(Ranking, self).__init__(output, tourney, 1)
         self.turn = turn
 
+    def getLitURL(self, request):
+        if not request.host.startswith('localhost'):
+            return request.route_url('lit_tourney', guid=self.tourney.guid)
+
     def getSubTitle(self):
         if self.turn is not None:
             return gettext('Ranking after %s round') % ordinal(self.turn)
@@ -956,6 +989,11 @@ class Results(TourneyPrintout):
         super(Results, self).__init__(output, tourney, 1)
         self.turn = turn
 
+    def getLitURL(self, request):
+        if not request.host.startswith('localhost') and self.turn:
+            return request.route_url('lit_tourney', guid=self.tourney.guid,
+                                     _query=dict(turn=self.turn))
+
     def getSubTitle(self):
         if self.turn:
             if [m.final for m in self.tourney.matches if m.turn == self.turn][0]:
@@ -1302,7 +1340,7 @@ class Badges(object):
                 if p:
                     yield c, p, r+1
 
-    def execute(self):
+    def execute(self, request):
         from pkg_resources import get_distribution
 
         dist = get_distribution('sol')
@@ -1368,48 +1406,52 @@ class Badges(object):
         from os.path import exists, join
 
         c = self.canvas
+        max_text_width = self.width
         center = self.width/2
 
         if self.tourney.championship.club.emblem:
             image = join(self.emblems, self.tourney.championship.club.emblem)
             if exists(image):
-                c.drawImage(image, 0, 0, self.width/5 * 2, self.height,
+                image_width = self.width/5 * 2
+                c.drawImage(image, 0, 0, image_width, self.height,
                             preserveAspectRatio=True)
-                center = self.width/10 * 7
+                max_text_width -= image_width
+                center = image_width + max_text_width/2
 
-        c.setFont(cardtitle_style.fontName,
-                  cardtitle_style.fontSize,
-                  cardtitle_style.leading)
-        c.drawCentredString(center, self.height-1*cm,
-                            self.tourney.description)
-        c.setFont(cardinfo_style.fontName,
-                  cardinfo_style.fontSize,
-                  cardinfo_style.leading)
+        style = reduce_fontsize_to_fit_width(self.tourney.description,
+                                             max_text_width, cardtitle_style)[0]
+        c.setFont(style.fontName, style.fontSize, style.leading)
+        c.drawCentredString(center, self.height-1*cm, self.tourney.description)
+
+        style = cardinfo_style
+        c.setFont(style.fontName, style.fontSize, style.leading)
         c.drawCentredString(center, self.height-1.6*cm,
                             self.tourney.date.strftime(gettext('%m-%d-%Y')))
+
+        style = reduce_fontsize_to_fit_width(self.tourney.championship.description,
+                                             max_text_width, cardinfo_style)[0]
+        c.setFont(style.fontName, style.fontSize, style.leading)
         c.drawCentredString(center, self.height-2.2*cm,
                             self.tourney.championship.description)
+
         if rank and self.tourney.prized:
-            c.setFont(subtitle_style.fontName,
-                      subtitle_style.fontSize,
-                      subtitle_style.leading)
+            style = subtitle_style
+            c.setFont(style.fontName, style.fontSize, style.leading)
             c.drawCentredString(center, self.height-3*cm, str(rank))
-        c.setFont(badgename_style.fontName,
-                  badgename_style.fontSize,
-                  badgename_style.leading)
+
         caption = player.caption(html=False)
-        if c.stringWidth(caption) > (self.width-center)*1.8:
-            c.setFont(cardname_style.fontName,
-                      cardname_style.fontSize,
-                      cardname_style.leading)
+        style = reduce_fontsize_to_fit_width(caption, max_text_width, badgename_style)[0]
+        c.setFont(style.fontName, style.fontSize, style.leading)
         c.drawCentredString(center, self.height-3.7*cm, caption)
-        c.setFont(cardname_style.fontName,
-                  cardname_style.fontSize,
-                  cardname_style.leading)
+
+        style = cardname_style
+        c.setFont(style.fontName, style.fontSize, style.leading)
+
         rating = self.tourney.rating
         if rating is not None:
             rate = rating.getPlayerRating(player).rate
             c.drawCentredString(center, self.height-4.1*cm, str(rate))
+
         if competitor.player1Nationality:
             from gettext import translation
             from pycountry import LOCALES_DIR, countries
@@ -1442,17 +1484,15 @@ class Badges(object):
                 s += '…'
             return s
 
-        c.setFont(cardsmall_style.fontName,
-                  cardsmall_style.fontSize,
-                  cardsmall_style.leading)
+        c.setFont(cardsmall_style.fontName, cardsmall_style.fontSize, cardsmall_style.leading)
+
+        c.drawCentredString(1.8*cm, self.height-1*cm, gettext('You met...'))
+        c.drawString(0.3*cm, self.height-1.25*cm, gettext('Opponent'))
 
-        c.drawCentredString(1.8*cm, self.height-1*cm,
-                            gettext('You met...'))
-        c.drawString(0.3*cm, self.height-1.25*cm,
-                     gettext('Opponent'))
         # TRANSLATORS: this is the "score of this player" in the badge
         your = gettext('your')
         c.drawRightString(3.1*cm, self.height-1.25*cm, your)
+
         # TRANSLATORS: this is the "opponent score" in the badge
         his = gettext('his')
         c.drawRightString(3.4*cm, self.height-1.25*cm, his)
