@@ -606,7 +606,7 @@ Ext.define('SoL.module.Players', {
 
                 win = desktop.createWindow({
                     id: me.id,
-                    title: me.launcherText + filteredOn,
+                    title: (me.windowTitle || me.launcherText) + filteredOn,
                     taskbuttonTooltip: me.launcherTooltip,
                     iconCls: me.iconCls,
                     items: [config],
@@ -841,6 +841,23 @@ Ext.define('SoL.module.Players.MergeTarget', {
 });
 
 
+Ext.define('SoL.module.MyPlayers', {
+    extend: 'SoL.module.Players',
+
+    id: 'my-players-win',
+    iconCls: 'players-icon',
+    launcherText: null, // don't show an entry in the start menu
+
+    init: function() {
+        var me = this;
+        var user = me.app.user;
+        me.config.dataURL += '?filter_idowner=' + (user.is_admin ? 'NULL' : user.user_id);
+        me.windowTitle = Ext.String.format(_('Players managed by {0}'), user.fullname);
+        me.callParent();
+    }
+});
+
+
 var phoneNumberRE = /^\+?([0-9]+ ?[0-9]+)*$/;
 Ext.apply(Ext.form.field.VTypes, {
     phone: function(val, field) {
