@@ -491,7 +491,12 @@ Ext.define('SoL.module.Tourneys', {
                         duration: 45,
                         prealarm: 5,
                         couplings: couplings || 'serial'
-                    }
+                    },
+                    filters: [{
+                        property: 'date',
+                        value: new Date(),
+                        operator: '<='
+                    }]
                 }, config);
 
                 if(caller == 'championships') {
@@ -529,7 +534,7 @@ Ext.define('SoL.module.Tourneys', {
 
                 win = desktop.createWindow({
                     id: me.id,
-                    title: me.launcherText + filteredOn,
+                    title: (me.windowTitle || me.launcherText) + filteredOn,
                     taskbuttonTooltip: me.launcherTooltip,
                     iconCls: me.iconCls,
                     items: [config],
@@ -597,3 +602,20 @@ Ext.define('SoL.module.Tourneys', {
         }
     }
 });
+
+
+Ext.define('SoL.module.MyTourneys', {
+    extend: 'SoL.module.Tourneys',
+
+    id: 'my-tourneys-win',
+    iconCls: 'tourneys-icon',
+    launcherText: null, // don't show an entry in the start menu
+
+    init: function() {
+        var me = this;
+        var user = me.app.user;
+        me.config.dataURL += '?filter_idowner=' + (user.is_admin ? 'NULL' : user.user_id);
+        me.windowTitle = Ext.String.format(_('Tourneys managed by {0}'), user.fullname);
+        me.callParent();
+    }
+});
